@@ -156,7 +156,7 @@ class PavlovADM(Cmd):
 
 	def _getitem(self):
 		with open(expanduser(self.itemtbl), 'r') as ifh:
-			items = [l.split(',')[0] for l in ifh.readlines()]
+			items = [l.split(',')[0] for l in list(ifh.readlines())[1:]]
 		ask = [
             iList(
                 'item',
